package com.ruoyi.web.controller.system;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.SysCompanyTemplate;
import com.ruoyi.system.service.ISysCompanyTemplateService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 企业模板配置Controller
 * 
 * @author lixu
 * @date 2025-05-21
 */
@RestController
@RequestMapping("/system/template")
public class SysCompanyTemplateController extends BaseController
{
    @Autowired
    private ISysCompanyTemplateService sysCompanyTemplateService;

    /**
     * 查询企业模板列表
     */
    @PreAuthorize("@ss.hasPermi('system:template:list')")
    @GetMapping("/list")
    public TableDataInfo list(SysCompanyTemplate sysCompanyTemplate)
    {
        startPage();
        List<SysCompanyTemplate> list = sysCompanyTemplateService.selectSysCompanyTemplateList(sysCompanyTemplate);
        return getDataTable(list);
    }

    /**
     * 导出企业模板列表
     */
    @PreAuthorize("@ss.hasPermi('system:template:export')")
    @Log(title = "导出企业配置列表", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, SysCompanyTemplate sysCompanyTemplate)
    {
        List<SysCompanyTemplate> list = sysCompanyTemplateService.selectSysCompanyTemplateList(sysCompanyTemplate);
        ExcelUtil<SysCompanyTemplate> util = new ExcelUtil<SysCompanyTemplate>(SysCompanyTemplate.class);
        util.exportExcel(response, list, "企业配置数据");
    }

    /**
     * 获取企业模板详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:template:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(sysCompanyTemplateService.selectSysCompanyTemplateById(id));
    }

    /**
     * 新增企业模板
     */
    @PreAuthorize("@ss.hasPermi('system:template:add')")
    @Log(title = "新增企业模板信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody SysCompanyTemplate sysCompanyTemplate)
    {
        return toAjax(sysCompanyTemplateService.insertSysCompanyTemplate(sysCompanyTemplate));
    }

    /**
     * 修改企业模板
     */
    @PreAuthorize("@ss.hasPermi('system:template:edit')")
    @Log(title = "修改企业模板信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody SysCompanyTemplate sysCompanyTemplate)
    {
        return toAjax(sysCompanyTemplateService.updateSysCompanyTemplate(sysCompanyTemplate));
    }

    /**
     * 删除企业模板
     */
    @PreAuthorize("@ss.hasPermi('system:template:remove')")
    @Log(title = "删除企业模板信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(sysCompanyTemplateService.deleteSysCompanyTemplateByIds(ids));
    }
}
