package com.ruoyi.common.utils;

public class VersionUtils {
    /**
     * 将版本号加1
     * @param version 当前版本号，格式为"V"后跟一个数字，例如"V1"
     * @return 新版本号，例如传入"V1"返回"V2"
     * @throws IllegalArgumentException 如果版本号格式不正确
     */
    public static String incrementVersion(String version) {
        if (version == null || version.isEmpty()) {
            return "V0";
        }
        if (!version.startsWith("V")) {
            throw new IllegalArgumentException("版本号必须以'V'开头");
        }
        String numberPart = version.substring(1);
        if (!numberPart.matches("\\d+")) {
            throw new IllegalArgumentException("版本号格式不正确，应为'V'后跟一个数字");
        }
        int number = Integer.parseInt(numberPart);
        int incrementedNumber = number + 1;
        return "V" + incrementedNumber;
    }
}
