package com.ruoyi.system.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.SysRepoMapper;
import com.ruoyi.system.domain.SysRepo;
import com.ruoyi.system.service.ISysRepoService;

/**
 * 仓库文件Service业务层处理
 * 
 * @author lixu
 * @date 2025-05-15
 */
@Service
public class SysRepoServiceImpl implements ISysRepoService 
{
    @Autowired
    private SysRepoMapper sysRepoMapper;

    /**
     * 查询仓库文件
     * 
     * @param repoId 仓库文件ID
     * @return 仓库文件信息
     */
    @Override
    public SysRepo selectSysRepoByRepoId(Long repoId)
    {
        return sysRepoMapper.selectSysRepoByRepoId(repoId);
    }

    /**
     * 查询仓库文件列表
     * 
     * @param sysRepo 仓库文件信息
     * @return 仓库文件列表
     */
    @Override
    public List<SysRepo> selectSysRepoList(SysRepo sysRepo)
    {
        return sysRepoMapper.selectSysRepoList(sysRepo);
    }

    /**
     * 新增仓库文件
     * 
     * @param sysRepo 仓库文件信息
     * @return 结果
     */
    @Override
    public int insertSysRepo(SysRepo sysRepo)
    {
        sysRepo.setCreateTime(DateUtils.getNowDate());
        return sysRepoMapper.insertSysRepo(sysRepo);
    }

    /**
     * 修改仓库文件信息
     * 
     * @param sysRepo 仓库文件信息
     * @return 结果
     */
    @Override
    public int updateSysRepo(SysRepo sysRepo)
    {
        sysRepo.setUpdateTime(DateUtils.getNowDate());
        return sysRepoMapper.updateSysRepo(sysRepo);
    }

    /**
     * 批量删除仓库文件
     * 
     * @param repoIds 需要删除的仓库文件ID集合
     * @return 结果
     */
    @Override
    public int deleteSysRepoByRepoIds(Long[] repoIds)
    {
        return sysRepoMapper.deleteSysRepoByRepoIds(repoIds);
    }

    /**
     * 删除仓库文件信息
     * 
     * @param repoId 仓库文件ID
     * @return 结果
     */
    @Override
    public int deleteSysRepoByRepoId(Long repoId)
    {
        return sysRepoMapper.deleteSysRepoByRepoId(repoId);
    }
}
